@@ -290,7 +290,8 @@ class PyGit:
         for p in self._projects:
 
             repo  = git.Repo(p["path"])
-            items = repo.index.diff(None)
+            itemsChangedFiles        = repo.index.diff(None)
+            itemsChangesToBeCommited = repo.index.diff("HEAD")
 
             nothingToCommit = True
             activeBranch    = str(repo.active_branch.name)
@@ -298,13 +299,22 @@ class PyGit:
             msg = Colors.BLUE + "Checking Status " + Colors.GREEN + "project {}[{}{}]".format(Colors.IBLUE + projectName.ljust(lenLabelProject-1,"-")+ ">" + Colors.GREEN, Emoticons.blocks() ,Colors.IGREEN + activeBranch + Colors.GREEN)
             msg = Console.addToMsg(LABEL_LENGTH,msg,magnifier)
             
-            if len(items) > 0:
+            if len(itemsChangedFiles) > 0:
                 nothingToCommit = False
                 msg += "\n    " + Emoticons.pointRight() + Colors.GREEN + " Changed files:"
                 idx_chg_files = 0
-                for item in items:
+                for item in itemsChangedFiles:
                     idx_chg_files  += 1
                     msg += "\n       " + Colors.GREEN + "{:02d} ".format(idx_chg_files) + Colors.WHITE + ">>" + Colors.RESET + " " + item.a_path   
+
+            if len(itemsChangesToBeCommited) > 0:
+                nothingToCommit = False
+                msg += "\n    " + Emoticons.pointRight() + Colors.GREEN + " Changes to be commited:"
+                idx_chg_files = 0
+                for item in itemsChangesToBeCommited:
+                    idx_chg_files  += 1
+                    msg += "\n       " + Colors.GREEN + "{:02d} ".format(idx_chg_files) + Colors.WHITE + ">>" + Colors.RESET + " " + Colors.BG_BLUE + item.a_path + Colors.RESET
+
             files = repo.untracked_files
             if len(files) > 0:
                 nothingToCommit = False
