@@ -225,8 +225,8 @@ class PyMvnGit:
     def _currentDir(self):
         currentDirectory = os.getcwd()
         #For testing/development
-        return "/home/ualter/Developer/teachstore"
-        #return currentDirectory
+        #return "/home/ualter/Developer/teachstore"
+        return currentDirectory
 
     def _encodeDirectoryName(self, directory):
         return directory.replace("\\","_").replace("/","_").replace(":","_drive_").lower()
